/**
 * @file    shellmatta_ymodem.h
 * @brief   ymodem functions of shellmatta
 * @author  Simon Fischer <dev@s-fischer.net>
 */

#ifndef _SHELLMATTA_YMODEM_H_
#define _SHELLMATTA_YMODEM_H_

#include <stdint.h>
#include "shellmatta.h"

/**
 * @brief return codes for receive byte function of ymodem module
*/
typedef enum {
    SOH_RECEIVED,
    STX_RECEIVED,
    EOT_RECEIVED,
    CA_RECEIVED,
    DATA_RECEIVED,
    ERROR
} shellmatta_ymodem_rcv_retcode_t;

typedef enum {
    YMODEM_NONE,   /* no data is transmitted */
    YMODEM_HEADER, /* header packet is transmittet */
    YMODEM_BODY,   /* data packet is transmitted */
    YMODEM_FOOTER  /* end of transmission packet is transmitted */
} shellmatta_ymodem_datatype_t;


void shellmatta_ymodem_receive_packet(  shellmatta_handle_t             handle, 
                                        uint8_t                         byteIn);

shellmatta_retCode_t shellmatta_ymodem_processByte( shellmatta_handle_t handle,
                                                    char                byte);

shellmatta_retCode_t shellmatta_ymodem_poll(        shellmatta_handle_t handle);

void shellmatta_ymodem_set_state(       shellmatta_handle_t             handle, 
                                        shellmatta_ymodem_state_t       newState);

shellmatta_ymodem_state_t shellmatta_ymodem_get_state(          shellmatta_handle_t handle);

shellmatta_ymodem_rcv_retcode_t shellmatta_ymodem_receive_byte( shellmatta_handle_t handle, 
                                                                uint8_t             byteIn);

void shellmatta_ymodem_ack(             shellmatta_handle_t handle);

void shellmatta_ymodem_nak(             shellmatta_handle_t handle);

void shellmatta_ymodem_check_packet(    shellmatta_handle_t handle);

void shellmatta_ymodem_reset(           shellmatta_ymodem_t *ymodem,
                                        bool                doCancel);

shellmatta_ymodem_datatype_t shellmatta_ymodem_get_current_datatype(void);

#endif /* _SHELLMATTA_YMODEM_H_ */
